==> emodpy_tbhiv-0.1.8.dev0-py3-none-any.whl: tests/test_ramp.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.ramp_dtn as ramp
import emod_api.campaign as camp


class Testramp(TestIntervention):
    """
    Test DiagnosticTreatNeg intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(ramp.RampDTN, "DiagnosticTreatNeg", "camp_ramp.json", False)

    def test_all(self):
        camp.set_schema( self.schema )
        expected_trigger_treatment_list = ["Infected"]
        trigger_treatment_list = copy.deepcopy(expected_trigger_treatment_list)
        ramp_time = 20
        base_sensitivity_smearpos = 0.2
        base_sensitivity_smearneg = 0.6
        base_sensitivity_smearpos2 = 0.3
        base_sensitivity_smearneg2 = 0.9
        treatment_fraction = 0.7
        treatment_fraction2 = 0.65
        pos_event = 'TBTestPositive'
        neg_event = 'TBTestNegative'
        defaulters_event = 'TBTestDefault'
        pos_event2 = 'TBTestPositive'
        neg_event2 = 'TBTestNegative'
        defaulters_event2 = 'TBTestDefault'
        start_day = 1
        duration = 1000
        property_restrictions_list = ["test:test"]
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 0
        black_trigger = 'Blackout'
        event_name = 'RampDTN_intervention'
        intervention_class = "DiagnosticTreatNeg"
        event = ramp.RampDTN(camp, trigger_treatment_list, ramp_time, base_sensitivity_smearpos, base_sensitivity_smearneg,
                             base_sensitivity_smearpos2, base_sensitivity_smearneg2, treatment_fraction,
                             treatment_fraction2, pos_event, neg_event, defaulters_event, pos_event2, neg_event2,
                             defaulters_event2, start_day, duration, property_restrictions_list, nodeIDs, black_period,
                             black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_ramp.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention1 = ic["Actual_IndividualIntervention_Config"]
        intervention2 = ic["Not_Covered_IndividualIntervention_Configs"][0]

        self.assertEqual(intervention1["Base_Sensitivity"], base_sensitivity_smearpos)
        self.assertEqual(intervention1["Base_Specificity"], 1.0 - base_sensitivity_smearneg)
        self.assertEqual(intervention1["Defaulters_Event"], defaulters_event)
        self.assertEqual(intervention1["Negative_Diagnosis_Event"], neg_event)
        self.assertEqual(intervention1["Positive_Diagnosis_Event"], pos_event)
        self.assertEqual(intervention1["Treatment_Fraction"], treatment_fraction)
        self.assertEqual(intervention1["class"], intervention_class)

        self.assertEqual(intervention2["Base_Sensitivity"], base_sensitivity_smearpos2)
        self.assertEqual(intervention2["Base_Specificity"], 1.0 - base_sensitivity_smearneg2)
        self.assertEqual(intervention2["Defaulters_Event"], defaulters_event2)
        self.assertEqual(intervention2["Negative_Diagnosis_Event"], neg_event2)
        self.assertEqual(intervention2["Positive_Diagnosis_Event"], pos_event2)
        self.assertEqual(intervention2["Treatment_Fraction"], treatment_fraction2)
        self.assertEqual(intervention2["class"], intervention_class)

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in
                                                           expected_property_restrictions_list])
        self.assertEqual(ic["Primary_Time_Constant"], ramp_time)
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(camp.pubsub_signals_pubbing,
                         [pos_event, neg_event, defaulters_event, pos_event2, neg_event2, defaulters_event2])

    def test_new_intervention_as_file(self, intervention_class_name='DiagnosticTreatNeg'):
        camp_filename = os.path.join(self.output, 'camp_ramp_as_file.json')
        super().new_intervention_as_file_test(ramp, camp_filename, intervention_class_name, is_multi=False)


if __name__ == '__main__':
    unittest.main()

==> emodpy_tbhiv-1.0.6.dev0-py3-none-any.whl: tests/test_ramp.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.ramp_dtn as ramp
import emod_api.campaign as camp


class Testramp(TestIntervention):
    """
    Test DiagnosticTreatNeg intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(ramp.RampDTN, "DiagnosticTreatNeg", "camp_ramp.json", False)

    def test_all(self):
        camp.set_schema( self.schema )
        expected_trigger_treatment_list = ["Births"]
        trigger_treatment_list = copy.deepcopy(expected_trigger_treatment_list)
        ramp_time = 20
        base_sensitivity_smearpos = 0.2
        base_sensitivity_smearneg = 0.6
        base_sensitivity_smearpos2 = 0.3
        base_sensitivity_smearneg2 = 0.9
        treatment_fraction = 0.7
        treatment_fraction2 = 0.65
        pos_event = 'TBTestPositive'
        neg_event = 'TBTestNegative'
        defaulters_event = 'TBTestDefault'
        pos_event2 = 'TBTestPositive'
        neg_event2 = 'TBTestNegative'
        defaulters_event2 = 'TBTestDefault'
        start_day = 1
        duration = 1000
        property_restrictions_list = ["test:test"]
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 0
        black_trigger = 'Blackout'
        event_name = 'RampDTN_intervention'
        intervention_class = "DiagnosticTreatNeg"
        event = ramp.RampDTN(camp, trigger_treatment_list, ramp_time, base_sensitivity_smearpos, base_sensitivity_smearneg,
                             base_sensitivity_smearpos2, base_sensitivity_smearneg2, treatment_fraction,
                             treatment_fraction2, pos_event, neg_event, defaulters_event, pos_event2, neg_event2,
                             defaulters_event2, start_day, duration, property_restrictions_list, nodeIDs, black_period,
                             black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_ramp.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention1 = ic["Actual_IndividualIntervention_Config"]
        intervention2 = ic["Not_Covered_IndividualIntervention_Configs"][0]

        self.assertEqual(intervention1["Base_Sensitivity"], base_sensitivity_smearpos)
        self.assertEqual(intervention1["Base_Specificity"], 1.0 - base_sensitivity_smearneg)
        self.assertEqual(intervention1["Defaulters_Event"], defaulters_event)
        self.assertEqual(intervention1["Negative_Diagnosis_Event"], neg_event)
        self.assertEqual(intervention1["Positive_Diagnosis_Event"], pos_event)
        self.assertEqual(intervention1["Treatment_Fraction"], treatment_fraction)
        self.assertEqual(intervention1["class"], intervention_class)

        self.assertEqual(intervention2["Base_Sensitivity"], base_sensitivity_smearpos2)
        self.assertEqual(intervention2["Base_Specificity"], 1.0 - base_sensitivity_smearneg2)
        self.assertEqual(intervention2["Defaulters_Event"], defaulters_event2)
        self.assertEqual(intervention2["Negative_Diagnosis_Event"], neg_event2)
        self.assertEqual(intervention2["Positive_Diagnosis_Event"], pos_event2)
        self.assertEqual(intervention2["Treatment_Fraction"], treatment_fraction2)
        self.assertEqual(intervention2["class"], intervention_class)

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in
                                                           expected_property_restrictions_list])
        self.assertEqual(ic["Primary_Time_Constant"], ramp_time)
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(camp.pubsub_signals_pubbing,
                         [pos_event, neg_event, defaulters_event, pos_event2, neg_event2, defaulters_event2])

    def test_new_intervention_as_file(self, intervention_class_name='DiagnosticTreatNeg'):
        camp_filename = os.path.join(self.output, 'camp_ramp_as_file.json')
        super().new_intervention_as_file_test(ramp, camp_filename, intervention_class_name, is_multi=False)


if __name__ == '__main__':
    unittest.main()
